/* 
 Copyright (c) 2014-2024 Marvell International Ltd., All Rights Reserved
 Redistribution and use in source and binary forms, with or without modification, 
 are permitted provided that the following conditions are met:

 1. Redistributions of source code must retain the above copyright notice, this list 
    of conditions and the following disclaimer.
 2. Redistributions in binary form must reproduce the above copyright notice, this list 
    of conditions and the following disclaimer in the documentation and/or other materials 
    provided with the distribution.
    
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS 
 OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY 
 AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR 
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
 OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.
*/                              

#ifndef MTD_OS_APITYPES_H
#define MTD_OS_APITYPES_H

#ifdef MTD_MRVL_DEMO_BOARD    /* for demo board environment */
#define MTD_MARVELL_TEST_ENV 1 /* set to 0 for host environment */
                              /* set to 1 to build sample code */
                              /* to interface to Marvell DB via SMI board */
#define MTD_STATIC
#else
#define MTD_MARVELL_TEST_ENV 0
#define MTD_STATIC static
#endif

#include <stdint.h>
#define C_LINKAGE 1 /* set to 1 if C compile/linkage on C files is desired with C++ */

#if C_LINKAGE
#if defined __cplusplus
    extern "C" {
#endif
#endif

#undef IN
#define IN
#undef OUT
#define OUT
#undef INOUT
#define INOUT

#define MTD_OK       0    /* Operation succeeded */
#define MTD_FAIL     1    /* Operation failed    */
#define MTD_PENDING  2    /* Pending  */

#define MTD_ENABLE   1    /* feature enable */
#define MTD_DISABLE  0    /* feature disable */

typedef void      MTD_VOID;
typedef char      MTD_8;
typedef short     MTD_16; 
typedef long      MTD_32;
typedef long long MTD_64;

typedef uint8_t         MTD_U8;
typedef int8_t          MTD_S8;
typedef uint16_t        MTD_U16;
typedef uint32_t        MTD_U32;
typedef unsigned int    MTD_UINT;
typedef int             MTD_INT;
typedef int16_t         MTD_S16;
typedef void* MTD_PVOID;

typedef unsigned long long  MTD_U64;

typedef struct _MTD_DEV MTD_DEV;
typedef MTD_DEV *MTD_DEV_PTR;

typedef enum {
    MTD_FALSE = 0,
    MTD_TRUE  = 1
} MTD_BOOL;


typedef MTD_U32 MTD_STATUS;

struct _MTD_DEV
{
    MTD_U32         deviceId;      /* type of device and capabilities */
    MTD_BOOL        devEnabled;    /* flag checked if device structure is initialized */
    MTD_U8          numPortsPerDevice;      /* number of ports per device */
    MTD_PVOID       appData;       /* anything user wants to pass through to lower level device driver */
};

#define MTD_UNUSED_PARAMETER(_x) (MTD_VOID)(_x) /* to purposely avoid compiler warnings on unused parameters */  

#if C_LINKAGE
#if defined __cplusplus
}
#endif
#endif

#endif /* defined MTD_OS_APITYPES_H */


