/* 
 Copyright (c) 2014-2024 Marvell International Ltd., All Rights Reserved
 Redistribution and use in source and binary forms, with or without modification, 
 are permitted provided that the following conditions are met:

 1. Redistributions of source code must retain the above copyright notice, this list 
    of conditions and the following disclaimer.
 2. Redistributions in binary form must reproduce the above copyright notice, this list 
    of conditions and the following disclaimer in the documentation and/or other materials 
    provided with the distribution.
    
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS 
 OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY 
 AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR 
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
 OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.
*/


#include "openSourceMtdAPITypes.h"
#include "openSourceMtdUser.h"

#if MTD_MARVELL_TEST_ENV
#include <Windows.h>
#include <WinError.h>
#include <stdio.h>
#include "tstSMIInterface.h"
#endif

#ifdef MTD_DEBUG_PRINT 
#include "stdarg.h"
#include "stdio.h"
#endif

#if MTD_MARVELL_TEST_ENV==0
/*******************************************************************
 PORT THESE FUNCTIONS
 *******************************************************************/

MTD_STATUS mtdHwXmdioWrite
( 
    IN MTD_DEV_PTR devPtr,
    IN MTD_U16 port, 
    IN MTD_U16 dev, 
    IN MTD_U16 reg, 
    IN MTD_U16 value
)
{
    MTD_STATUS result = MTD_FAIL;


    /* target Clause 45 write function goes here */

    return result;
}

MTD_STATUS mtdHwXmdioRead
(
    IN MTD_DEV_PTR devPtr,
    IN MTD_U16 port, 
    IN MTD_U16 dev, 
    IN MTD_U16 reg,
    OUT MTD_U16 *data
)
{    
    MTD_STATUS result = MTD_FAIL;

    /* target Clause 45 read function goes here */

    return result;
}

MTD_STATUS mtdWait
(
    IN MTD_DEV_PTR devPtr,
    IN MTD_UINT x
)
{
    MTD_STATUS result = MTD_FAIL;

    /* target sleep for x milliseconds goes here */
    
    return result;
}

/*******************************************************************
   END: PORT THESE FUNCTIONS
 *******************************************************************/
#else /* MTD_MARVELL_TEST_ENV */
MTD_STATUS mtdHwXmdioWrite
( 
    IN MTD_DEV_PTR devPtr,
    IN MTD_U16 port, 
    IN MTD_U16 dev, 
    IN MTD_U16 reg, 
    IN MTD_U16 value
)
{
    MTD_STATUS result = MTD_OK;

    if (MdioWrite(devPtr,
                  (unsigned long)port,
                  (unsigned long)dev, 
                  (unsigned long)reg, 
                  (unsigned short)value) < S_OK)
    {
        result = MTD_FAIL;
        MTD_DBG_INFO("MdioWrite 0x%04X failed to port=%d, dev=%d, reg=0x%04X\n", (unsigned)(value),(unsigned)port,(unsigned)dev,(unsigned)reg);
    }

    return result;
}

MTD_STATUS mtdHwXmdioRead
(
    IN MTD_DEV_PTR devPtr,
    IN MTD_U16 port, 
    IN MTD_U16 dev, 
    IN MTD_U16 reg,
    OUT MTD_U16 *data
)
{    
    MTD_STATUS result = MTD_OK;
    HRESULT retCode;

    *data = (MTD_U16)MdioRead(devPtr,
                              (unsigned long)port,
                              (unsigned long)dev,
                              (unsigned long)reg,
                              &retCode);
    if (retCode < S_OK)
    {
        result = MTD_FAIL;
        MTD_DBG_INFO("MdioRead failed from port=%d, dev=%d, reg=0x%04X\n", (unsigned)port,(unsigned)dev,(unsigned)reg);
    }

    return result;
}

MTD_STATUS mtdWait
(
    IN MTD_DEV_PTR devPtr,
    IN MTD_UINT x
)
{
    Sleep(x);
    return MTD_OK;
}

#endif /* MTD_MARVELL_TEST_ENV */


#ifdef MTD_DEBUG_PRINT
MTD_DBG_LEVEL mtd_debug_level = MTD_DBG_ALL_LVL; /* Set default debug level */

/*******************************************************************************
* mtdDbgPrint
*
* DESCRIPTION:
*       .
*
* INPUTS:
*       debug_level - allows control of how much is printed
*               MTD_DBG_OFF_LVL  - prints nothing
*               MTD_DBG_ERR_LVL - for error messages
*               MTD_DBG_ALL_LVL - for informational messages
*
* OUTPUTS:
*       None
*
* RETURNS:
*       None
*
* COMMENTS:
*       Set global mtd_debug_level to MTD_DBG_OFF_LVL to turn off all printing, or
*       MTD_DBG_ERR_LVL to print only errors, or MTD_DBG_ALL_LVL for both errors
*       and informational messages. This can be done during run time or
*       the global default can be changed at compile time to change the
*       run-time behavior.
*
*       Remove the define MTD_DEBUG_PRINT to remove all printing code (may need some 
*       modifications on some compilers).
*
*******************************************************************************/
void mtdDbgPrint(
    FILE *stream, 
    MTD_DBG_LEVEL debug_level, 
    char* format, ...
)
{
    va_list argP;
    char dbgStr[1000] = "";

#ifdef MTD_PY_DEBUG
    if (debug_level)
    {
        if (debug_level <= mtd_debug_level)
        {
            va_start(argP, format);

            vsprintf(dbgStr, format, argP);

            tstApiDbgWrite(debug_level, dbgStr);

            va_end(argP);
        }
    }
#else
    if (debug_level)
    {
        if (debug_level <= mtd_debug_level)
        {
            va_start(argP, format);

            vsprintf(dbgStr, format, argP);

            fprintf(stream, dbgStr);

            va_end(argP);
        }
    }
#endif /* MTD_PY_DEBUG */
}
#else 

/* All printing code removed */

#endif /* DEBUG_MTD */

